;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "universal-sidecar" "20251021.212"
  "A universal sidecar buffer."
  '((emacs         "26.1")
    (magit-section "3.0.0"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "535cd1cd1c42bd8d375506e46c50fd976cc7ea0e"
  :revdesc "535cd1cd1c42"
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
